Summary: C++ wrapper library around CGAL for PostGIS
Name: SFCGAL
Version: 1.3.10
Release: 1%{?dist}
License: LGPLv2
URL: https://gitlab.com/Oslandia/SFCGAL/
Source: https://gitlab.com/Oslandia/SFCGAL/-/archive/v%{version}/SFCGAL-v%{version}.tar.bz2

BuildRequires: CGAL-devel
BuildRequires: cmake boost-thread, boost-system, boost-date-time, boost-serialization
BuildRequires: mpfr-devel, gmp-devel, gcc-c++

# See https://gitlab.com/Oslandia/SFCGAL/-/issues/245
ExcludeArch: armv7hl

%description
SFCGAL is a C++ wrapper library around CGAL with the aim of supporting
ISO 19107:2013 and OGC Simple Features Access 1.2 for 3D operations.

SFCGAL provides standard compliant geometry types and operations, that
can be accessed from its C or C++ APIs. PostGIS uses the C API, to
expose some SFCGAL's functions in spatial databases (cf. PostGIS
manual).

Geometry coordinates have an exact rational number representation and
can be either 2D or 3D.

Note: W: shared-lib-calls-exit /usr/lib64/libSFCGAL.so.1.3.8 exit@GLIBC_2.2.5

%package devel
Summary: The development files for SFCGAL
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Development headers and libraries for SFCGAL.

%prep
%autosetup -p0 -n SFCGAL-v%{version}

%build
%cmake -D LIB_INSTALL_DIR=%{_lib} -DBoost_NO_BOOST_CMAKE=BOOL:ON -DCMAKE_SKIP_RPATH:BOOL=YES .
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%doc AUTHORS README.md NEWS
%license LICENSE
%{_libdir}/libSFCGAL.so.*

%files devel
%{_includedir}/SFCGAL
%{_libdir}/libSFCGAL.so
%{_libdir}/pkgconfig/sfcgal.pc
%{_bindir}/sfcgal-config
%doc doc/ example/

%changelog
* Wed May 26 2021 Paul Wouters <paul.wouters@aiven.io> - 1.3.10-1
- Initial packaging for Fedora
- Cleanup for Fedora 34+
- Merged debian patches to support CGAL 5.x as per https://github.com/Oslandia/SFCGAL/pull/219

* Fri Oct 2 2020 Devrim Gündüz <devrim@gunduz.org> - 1.3.9-2
- We don't need CGAL dependency for CGAL >= 5.0 (Fedora 32 and above)

* Thu Oct 1 2020 Devrim Gündüz <devrim@gunduz.org> - 1.3.9-1
- Update to 1.3.9 for Fedora 33 (CGAL 5.1)

* Wed Aug 19 2020 Devrim Gündüz <devrim@gunduz.org> - 1.3.8-1
- Update to 1.3.8

* Thu Apr 23 2020 Devrim Gündüz <devrim@gunduz.org> - 1.3.7-4
- Add two patches for CGAL 5 builds

* Tue Mar 31 2020 Devrim Gündüz <devrim@gunduz.org> - 1.3.7-3
- Clarify dependencies on RHEL 8, per Talha Bin Rizwan.
- Depend on pgdg-srpm-macros

* Fri Jul 19 2019 John K. Harvey <john.harvey@crunchydata.com> - 1.3.7-2
- Fix broken macro

* Mon Jun 3 2019 Devrim Gündüz <devrim@gunduz.org> - 1.3.7-1
- Update to 1.3.7

* Mon Oct 15 2018 Devrim Gündüz <devrim@gunduz.org> - 1.3.2-1.1
- Rebuild against PostgreSQL 11.0

* Wed Sep 13 2017 Devrim Gündüz <devrim@gunduz.org> 1.3.2-1
- Update to 1.3.2 to support CGAL >= 4.10.1 on Fedora 26+

* Wed Jul 19 2017 Devrim Gündüz <devrim@gunduz.org> 1.2.2-2
- Also Requires CGAL, per Fahar Abbas (EDB QA)

* Thu Nov 19 2015 Oskari Saarenmaa <os@ohmu.fi> 1.2.2-1
- Update to 1.2.2 to support newer CGAL versions

* Fri Oct 30 2015 Devrim Gündüz <devrim@gunduz.org> 1.2.0-1
- Initial build for PostgreSQL YUM Repository.
